Struct PlaneData
struct PlaneData<T: Pixel> { ... }
Backing buffer for the Plane data
The buffer is padded and aligned according to the architecture-specific SIMD constraints.
Implementations
impl<T: Pixel> PlaneData<T>
fn new(len: usize) -> Self
impl<P, T> Receiver for PlaneData<T>
impl<T> Any for PlaneData<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PlaneData<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PlaneData<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for PlaneData<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Freeze for PlaneData<T>
impl<T> From for PlaneData<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for PlaneData<T>
impl<T> ToOwned for PlaneData<T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> Unpin for PlaneData<T>
impl<T> UnsafeUnpin for PlaneData<T>
impl<T> UnwindSafe for PlaneData<T>
impl<T, U> Into for PlaneData<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PlaneData<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PlaneData<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::clone::Clone + Pixel> Clone for PlaneData<T>
fn clone(self: &Self) -> PlaneData<T>
impl<T: $crate::cmp::Eq + Pixel> Eq for PlaneData<T>
impl<T: $crate::cmp::PartialEq + Pixel> PartialEq for PlaneData<T>
fn eq(self: &Self, other: &PlaneData<T>) -> bool
impl<T: $crate::fmt::Debug + Pixel> Debug for PlaneData<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: Pixel + Send> Send for PlaneData<T>
impl<T: Pixel + Sync> Sync for PlaneData<T>
impl<T: Pixel> Deref for PlaneData<T>
fn deref(self: &Self) -> &[T]
impl<T: Pixel> DerefMut for PlaneData<T>
fn deref_mut(self: &mut Self) -> &mut [T]